# 4. Bulk Platinum

We'll end this session with a bulk metal, so that we can put together solids and molecules in the next session.
Please see the input file in `in`.

The geometry is specified by a face-centered cubic lattice, and a single Pt ion within it (specified in lattice coordinates).

We now need to specify k-points to sample the Brillouin zone and smearing to sample the Fermi surface:

    kpoint-folding 8 8 8
    elec-smearing Fermi 0.01

The above commands create a 8 x 8 x 8 ($\Gamma$-centered by default) k-point mesh
to integrate over all possible Bloch wave vectors,
and select a Fermi smearing - effectively an elevated electron temperature - of 0.01 Eh.
This is roughly 10 times room temperature, but is needed to sample the sharp Fermi surface
reliably without Nyquist sampling issues at the practical k-point counts considered here.
(The code also supports Gauss, Cold and Methfessel-Paxton schemes
to minimize errors associated with the elevated temperature.)

There is no ionic geometry to optimize this time, but we specify `lattice-minimize`
to optimize the lattice vectors starting from the initial experimental geometry.
Finally, `dump Ionic Lattice` asks for lattice vectors to be output at every geometry optimization step.


## Run the calculation

As before, start an interactive session:

    beast-interactive

run:

    srun -n 29 -c 1 --hint=nomultithread jdftx -i in | tee out

and end the interactive session (`Ctrl+D`).
Note that we now ask for several (29) MPI processes with one thread each.
JDFTx is MPI-parallelized over reduced k-points and spin, reported as `nStates` in the output file.
Previously, we always had nStates = 1 and could only use one process (with remaining parallelization using threads).
Now, we have 29 states (reduced from 8 x 8 x 8 = 512 by symmetries), which we can run on one process each.
This uses 29 of the 32 physical cores on each Cori node.

(In practice, use `srun -n 1 jdftx -ni in` to perform a quick dry-run (no actual calculation)
to find `nStates` in order to decide the optimal parallelization strategy.)

In the lattice minimization output, notice that each step reports the stress and strain additionally.
The final strain (relative to initial) at convergence is 1.3\%: the lattice expands from experiment because PBE GGA underbinds solids.

Whenever we do lattice optimization, we must repeat the calculation till the strain within a run is small.
This is because the PW basis is kept fixed when the lattice changes to enable a smooth energy landscape for minimization.
However, the PW basis at a given KE cutoff depends on the lattice, and so we need to re-check convergence
and should only stop when the lattice does not change appreciably in a given run.

To continue, uncomment the `include jdftx.lattice` line and comment out the `lattice` command in `in`.
Run the code again now, and it will start with the lattice optimized in the previous run.
When we run it the second time, the strain is -0.001\%, and we don't need to rerun lattice optimization again.

## Visualization

Open the `Visualize.ipynb` in this directory to visualize the bulk Pt lattice.
